==> cx88-1.4.1.tar.gz: cx88-1.4.1/client/cx88_url_capture.h <==
/*-
 * Copyright 2007,2008 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __CX88_URL_CAPTURE_H__
#define __CX88_URL_CAPTURE_H__

#include <sys/types.h>
#include "cx88_capture.h"

#define CX88_DEFAULT_MTU      1500

class cx88_url_capture
   : public cx88_capture
{
   public:
      
      cx88_url_capture(const std::string &id, const char *addr, int &error, size_t mtu = CX88_DEFAULT_MTU);
      
      virtual ~cx88_url_capture(void);
      
   protected:
      
      virtual void process_buffer(void *data, size_t num_bytes, size_t packet_size);
      
      int m_socket;
      size_t m_mtu;
   
};

#endif

==> cx88-1.4.8.tar.gz: cx88-1.4.8/client/cx88_url_capture.h <==
/*-
 * Copyright 2007,2008 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __CX88_URL_CAPTURE_H__
#define __CX88_URL_CAPTURE_H__

#include <sys/types.h>
#include "cx88_capture.h"

#define CX88_DEFAULT_MTU      1500

class cx88_url_capture
   : public cx88_capture
{
   public:

      enum cx88_url_protocol_t
      {
         CX88_URL_PROTO_UDP,
         CX88_URL_PROTO_TCP
      };

      cx88_url_capture(const std::string &id, cx88_url_protocol_t protocol, const char *hostname, int &error, size_t mtu = CX88_DEFAULT_MTU);
      
      virtual ~cx88_url_capture(void);
      
   protected:
      
      virtual void process_buffer(void *data, size_t num_bytes, size_t packet_size);
      
      int m_socket;
      size_t m_mtu;
   
};

#endif
